@@ -237,10 +237,11 @@ class NoCloudNetworkConfigV1Parser(object):
         networks = []
         services = []
 
-        network_config = network_config.get('network') \
-            if network_config else {}
-        network_config = network_config.get('config') \
-            if network_config else None
+        if network_config and network_config.get('network'):
+            network_config = network_config.get('network')
+        if network_config:
+            network_config = network_config.get('config')
+
         if not network_config:
             LOG.warning("Network configuration is empty")
             return
@@ -479,8 +480,9 @@ class NoCloudNetworkConfigV2Parser(object):
         networks = []
         services = []
 
-        network_config = network_config.get('network') \
-            if network_config else {}
+        if network_config and network_config.get('network'):
+            network_config = network_config.get('network')
+
         if not network_config:
             LOG.warning("Network configuration is empty")
             return
@@ -529,29 +531,40 @@ class NoCloudNetworkConfigParser(object):
 
     @staticmethod
     def parse(network_data):
-        network_data_version = network_data.get("network", {}).get("version")
+        # we can have a network key in some cases
+        if network_data.get("network"):
+            network_data = network_data.get("network")
+        network_data_version = network_data.get("version")
+
         if network_data_version == 1:
             network_config_parser = NoCloudNetworkConfigV1Parser()
-            return network_config_parser.parse(network_data)
+        elif network_data_version == 2:
+            network_config_parser = NoCloudNetworkConfigV2Parser()
+        else:
+            raise exception.CloudbaseInitException(
+                "Unsupported network_data_version: '%s'"
+                % network_data_version)
 
-        return NoCloudNetworkConfigV2Parser().parse(network_data)
+        return network_config_parser.parse(network_data)
 
 
 class NoCloudConfigDriveService(baseconfigdrive.BaseConfigDriveService):
 
     def __init__(self):
         super(NoCloudConfigDriveService, self).__init__(
-            'cidata', 'meta-data')
+            'cidata', CONF.nocloud.metadata_file,
+            CONF.nocloud.userdata_file)
         self._meta_data = {}
 
     def get_user_data(self):
-        return self._get_cache_data("user-data")
+        return self._get_cache_data(self._userdata_file)
 
     def _get_meta_data(self):
         if self._meta_data:
             return self._meta_data
 
-        raw_meta_data = self._get_cache_data("meta-data", decode=True)
+        raw_meta_data = self._get_cache_data(
+            self._metadata_file, decode=True)
         try:
             self._meta_data = (
                 serialization.parse_json_yaml(raw_meta_data))
