@@ -165,7 +165,7 @@ class WindowsConfigDriveManager(base.BaseConfigDriveManager):
 
     def _get_config_drive_from_vfat(self, drive_label, metadata_file):
         for drive_path in self._osutils.get_physical_disks():
-            if vfat.is_vfat_drive(self._osutils, drive_path):
+            if vfat.is_vfat_drive(self._osutils, drive_path, drive_label):
                 LOG.info('Config Drive found on disk %r', drive_path)
                 vfat.copy_from_vfat_drive(self._osutils, drive_path,
                                           self.target_path)
