@@ -16,14 +16,10 @@
 import functools
 import posixpath
 import unittest
+import unittest.mock as mock
 
 import netaddr
 
-try:
-    import unittest.mock as mock
-except ImportError:
-    import mock
-
 from cloudbaseinit import conf as cloudbaseinit_conf
 from cloudbaseinit import exception
 from cloudbaseinit.metadata.services import base
