@@ -14,12 +14,8 @@
 
 import os
 import unittest
-
-try:
-    import unittest.mock as mock
-except ImportError:
-    import mock
-from six.moves.urllib import error
+import unittest.mock as mock
+from urllib import error
 
 from cloudbaseinit import conf as cloudbaseinit_conf
 from cloudbaseinit.metadata.services import base
