@@ -16,11 +16,7 @@
 import re
 import textwrap
 import unittest
-
-try:
-    import unittest.mock as mock
-except ImportError:
-    import mock
+import unittest.mock as mock
 
 from cloudbaseinit.metadata.services import base
 from cloudbaseinit.metadata.services import opennebulaservice
@@ -126,7 +122,7 @@ class _TestOpenNebulaService(unittest.TestCase):
         self._service = opennebulaservice.OpenNebulaService()
 
 
-@mock.patch("six.moves.builtins.open", new=OPEN)
+@mock.patch("builtins.open", new=OPEN)
 class TestOpenNebulaService(_TestOpenNebulaService):
 
     @classmethod
