@@ -16,11 +16,7 @@
 import os
 import textwrap
 import unittest
-
-try:
-    import unittest.mock as mock
-except ImportError:
-    import mock
+import unittest.mock as mock
 
 from cloudbaseinit.plugins.common import base
 from cloudbaseinit.plugins.common import execcmd
