@@ -14,11 +14,7 @@
 
 import importlib
 import unittest
-
-try:
-    import unittest.mock as mock
-except ImportError:
-    import mock
+import unittest.mock as mock
 
 from cloudbaseinit import conf as cloudbaseinit_conf
 from cloudbaseinit import constant
@@ -33,12 +29,10 @@ class BootConfigPluginTest(unittest.TestCase):
 
     def setUp(self):
         self.mock_wmi = mock.MagicMock()
-        self._moves_mock = mock.MagicMock()
         patcher = mock.patch.dict(
             "sys.modules",
             {
                 "wmi": self.mock_wmi,
-                "six.moves": self._moves_mock,
                 'ctypes': mock.MagicMock(),
                 'ctypes.windll': mock.MagicMock(),
                 'ctypes.wintypes': mock.MagicMock(),
