@@ -15,11 +15,7 @@
 
 import importlib
 import unittest
-
-try:
-    import unittest.mock as mock
-except ImportError:
-    import mock
+import unittest.mock as mock
 
 from cloudbaseinit.plugins.common import base
 from cloudbaseinit.tests import testutils
