@@ -16,11 +16,7 @@
 import ctypes as _    # noqa
 import importlib
 import unittest
-
-try:
-    import unittest.mock as mock
-except ImportError:
-    import mock
+import unittest.mock as mock
 
 MODPATH = "cloudbaseinit.utils.windows.storage.factory"
 
