@@ -15,11 +15,7 @@
 
 import importlib
 import unittest
-
-try:
-    import unittest.mock as mock
-except ImportError:
-    import mock
+import unittest.mock as mock
 
 from cloudbaseinit import exception
 from cloudbaseinit.tests import testutils
@@ -31,15 +27,14 @@ class TestWSMStorageManager(unittest.TestCase):
     def setUp(self):
         self._mock_ctypes = mock.MagicMock()
         self.mock_wmi = mock.MagicMock()
-        self._moves_mock = mock.MagicMock()
-        self._winreg_mock = self._moves_mock.winreg
+        self._winreg_mock = mock.MagicMock()
         self._kernel32_mock = mock.MagicMock()
 
         patcher = mock.patch.dict(
             "sys.modules",
             {
                 "wmi": self.mock_wmi,
-                "six.moves": self._moves_mock,
+                "winreg": self._winreg_mock,
                 "ctypes": self._mock_ctypes,
                 "oslo_log": mock.MagicMock()
             }
