@@ -12,7 +12,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import imp
+import importlib
 import os
 
 from oslo_log import log as oslo_logging
@@ -21,6 +21,14 @@ from oslo_log import log as oslo_logging
 LOG = oslo_logging.getLogger(__name__)
 
 
+def load_module_from_path(module_name, path):
+    spec = importlib.util.spec_from_file_location(module_name, path)
+    module = importlib.util.module_from_spec(spec)
+    spec.loader.exec_module(module)
+
+    return module
+
+
 class ClassLoader(object):
 
     def load_class(self, class_path):
@@ -32,9 +40,7 @@ class ClassLoader(object):
     def load_module(self, path):
         module_name, file_ext = os.path.splitext(os.path.split(path)[-1])
 
-        if file_ext.lower() == '.py':
-            module = imp.load_source(module_name, path)
-        elif file_ext.lower() == '.pyc':
-            module = imp.load_compiled(module_name, path)
+        if file_ext.lower() in ['.py', '.pyc']:
+            module = load_module_from_path(module_name, path)
 
         return module
