@@ -28,9 +28,8 @@ def get_storage_manager():
 
     osutils = osutils_factory.get_os_utils()
     cl = classloader.ClassLoader()
-
     if os.name == "nt":
-        if osutils.check_os_version(10, 0):
+        if osutils.is_nano_server():
             # VDS is not available on Nano Server
             # WSM supersedes VDS since Windows Server 2012 / Windows 8
             return cl.load_class(class_paths["WSM"])()
